(* $Id: godi_profile.mli 1001 2012-06-06 21:03:57Z gerd $ *)

(* Profiles: A profile determines from where to get packages, and which
   versions of packages to install. Also, one can include patches.

   Profiles only cover source packages.
 *)

type profile =
    { prof_name : string;  
        (* The name. The initial profile is called "head_<section>" *)
      prof_comment : string;  (* for the user *)
      prof_section : string;  (* The section *)
      prof_sources : prof_source list;
      prof_origin : string option;
        (* Optional URL of WebDAV server for profile uploads and refreshes *)
      prof_options : (string * string) list;
        (* package options *)
      prof_patches : (string * string) list;
        (* profile patches as pairs [(filename,data)]. The [filename]
	   has the form [<cat>/<pkgname>/<patchname>].
	 *)
      prof_archive : bool;
    }

and prof_source =
    { prof_source : string;   (* Symbol of the source *)
      prof_enable_condition : [ `Always | `Tools ];
      prof_include : Godi_versions.dependency list;
        (* Which packages to include. This list enumerates the packages
	   with version constraints. The package name "*" can be used
	   to refer to all unmentioned packages here, e.g.
	   ["*", Any] means to include all other packages in any version.

	   It is allowed to include several version constrains for the
	   same package: ["p1", Ge "1.0"; "p1", Lt "2.0"], for a package
	   "p1" in any version >= 1.0 and < 2.0.
	 *)
      prof_build_sites : string list;
        (* This is appended to GODI_BUILD_SITES. May contain variables like
	   $(GODI_SECTION)
	 *)
      prof_master_sites : string list;
        (* List of URLs *)
    }

(* TODO: also specify profile patches *)

val read_profile_ini : Godi_file.filename -> profile
  (* Reads the passed "profile.ini" file *)

val write_profile_ini : Godi_file.filename -> profile -> unit
  (* Writes to the passed "profile.ini" file *)

val write_profile_conf : Godi_file.filename -> profile -> unit
  (* Generate the profile.conf file *)

val write_profile_patches : Godi_file.filename -> profile -> unit
  (* [write_profile_patches tree p]: Remove the file tree at [tree], and
     create a new one with the profile patches from [p].
     e.g. [tree] = <build>/profile-patches
   *)

val update_profile_patches : Godi_file.filename -> profile -> profile
  (* [update_profile_patches tree p]: reads all patches at [tree] and
     set [p.prof_patches] to the patches.
   *)

val list_profiles : Godi_file.filename -> string list
  (* [list_profiles d]: Lists the profiles at directory [d]. This means
     if [<d>/<profname>/profile.ini] exists, [profname] is returned.
   *)

val pack_profile : Godi_file.filename -> Godi_file.tmpdir -> Godi_file.filename
  (* [pack_profile ppath tdir]: packs the profile at [ppath] (i.e.
     we have [<ppath>/profile.ini]), and writes a file [<profname>.profile.tgz]
     into [tdir]. The full path of the resulting file is returned.
   *)

val unpack_profile : Godi_file.filename -> Godi_file.filename -> unit
  (* [unpack_profile proftgz d]: Unpacks the [profile.tgz] file [proftgz]
     and writes the contents to [d], i.e. the profile [p] will have
     path [<d>/<p>/profile.ini].

     Important: The input file must have a name [.../<name>.profile.tgz]!
   *)

val profile_match : profile -> Godi_types.wrapped_package -> bool
  (* Checks the passed package by profile criteria:
     - Only packages from the profile source(s) are accepted
     - The packages and package versions must match the conditions in
       prof_include

     Returns true if the package is acceptable.
   *)
